<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;


class UserController extends Controller
{
    /**
     * Display a listing of the users
     *
     * @param  \App\User  $model
     * @return \Illuminate\View\View
     */
    public function index(User $model)
    {
        return view('users.index', ['users' => $model->paginate(15)]);
    }

    /**
     * Show the form for creating a new user
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('users.create');
    }

    /**
     * Store a newly created user in storage
     *
     * @param  \App\Http\Requests\UserRequest  $request
     * @param  \App\User  $model
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request, User $model)
    {
        $data = $request->all();
       $email=$request->input('email');
       $name=$request->input('name');
       $password=$request->input('password');
        $role=$request->input('role');
       //vérification du mail ou doublon
        $d=User::where('email','=',$email)
            ->OrWhere('name','=',$name)
            ->get();
        if(count($d)>0){
            //return redirect()->route('user.index')->withStatus(__('Ce L\'Utilisateur existe déjà.'));
            $error="Désolé, l'une des informations de $name exite déjà.";
            return view('users.replay',compact('email','name','password','role','error'));
        }else{
           if(isset($data['photo'])){
             $name = $data['photo']->hashName();
             $data['photo']->move('uploads/users', $name);
             $model->create($request->merge(['password' => Hash::make($request->get('password'))])->all());
             
             $user = User::OrderBy('created_at','desc')->first();
             
             $user->photo = $name;
             
             $user->save();
         }else{
             $model->create($request->merge(['password' => Hash::make($request->get('password'))])->all());
          }
         return redirect()->route('user.index')->withStatus(__('Utilisateur crée avec succès.'));
         }
    }

    /**
     * Show the form for editing the specified user
     *
     * @param  \App\User  $user
     * @return \Illuminate\View\View
     */
    public function edit(User $user)
    {
        return view('users.edit', compact('user'));
    }

    /**
     * Update the specified user in storage
     *
     * @param  \App\Http\Requests\UserRequest  $request
     * @param  \App\User  $user
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(UserRequest $request, User  $user)
    {
        $user->update(
            $request->merge(['password' => Hash::make($request->get('password'))])
                ->except([$request->get('password') ? '' : 'password']
        ));

        return redirect()->route('user.index')->withStatus(__('User successfully updated.'));
    }

    /**
     * Remove the specified user from storage
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(User  $user)
    {
        $user->delete();

        return redirect()->route('user.index')->withStatus(__('User successfully deleted.'));
    }
}
